"""
Django settings for musicrate project.

Generated by 'django-admin startproject' using Django 4.1.4.

For more information on this file, see
https://docs.djangoproject.com/en/4.1/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/4.1/ref/settings/
"""

from os import getenv
from pathlib import Path

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/4.1/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = getenv('SECRET_KEY', 'django-insecure-ypch--45z9kid#om2z8b-s%_mdz9f^vec(*$0(8zdx_ru*ga=3')

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = getenv('ENVIRONMENT', 'development') == 'development'

if not DEBUG and SECRET_KEY.startswith('django-insecure'):
    raise RuntimeError('please provide a secure secret to SECRET_KEY')

ALLOWED_HOSTS = list(filter(lambda s: s != '', getenv('ALLOWED_HOSTS', '').split(',')))


# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'musicrate.core',
    'musicrate.host',
    'musicrate.vote',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'musicrate.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'musicrate.wsgi.application'


# Database
# https://docs.djangoproject.com/en/4.1/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.' + getenv('DB_ENGINE', 'sqlite3'),
        'NAME': getenv('DB_NAME', BASE_DIR / 'db.sqlite3'),
        'USER': getenv('DB_USER', ''),
        'PASSWORD': getenv('DB_PASSWORD', ''),
        'HOST': getenv('DB_HOST', ''),
        'PORT': getenv('DB_PORT', ''),
    }
}


# Password validation
# https://docs.djangoproject.com/en/4.1/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/4.1/topics/i18n/

LANGUAGE_CODE = 'de-de'

TIME_ZONE = 'Europe/Berlin'

USE_I18N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/4.1/howto/static-files/

STATIC_ROOT = BASE_DIR / 'static'
STATIC_URL = 'static/'

# Default primary key field type
# https://docs.djangoproject.com/en/4.1/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'

GOOGLE_API_KEY = getenv('GOOGLE_API_KEY')

REQUIRED_FIELDS = ['Band', 'Genre', 'Link 1', 'Link 2', 'Herkunft', 'Anmerkung']
SHEET_TO_MODEL = {
    'Band': ('name', False),
    'Genre': ('genre', False),
    'Link 1': ('link_1', True),
    'Link 2': ('link_2', True),
    'Herkunft': ('origin', True),
    'Anmerkung': ('comment', True),
}

YOUTUBE_RE = r'(?:|(?:|(?:http(?:|s):))//)(?:youtu\.be/|(?:|(?:m|www)\.)youtube\.com/watch\?v=)([-0-9A-Z_a-z]{11})'

RATING_CHOICES = (
    ('10', 'sehr gut'),
    ( '9', 'ziemlich gut'),
    ( '8', 'gut'),
    ( '7', 'eher gut'),
    ( '6', 'ok'),
    ( '5', 'naja'),
    ( '4', 'eher schlecht'),
    ( '3', 'schlecht'),
    ( '2', 'ziemlich schlecht'),
    ( '1', 'sehr schlecht'),
)

BREAK_INTERVAL = int(getenv('BREAK_INTERVAL', 30)) # minutes

LOGIN_URL = '/admin/login/'

ADVANCE_THRESHOLD = float(getenv('ADVANCE_THRESHOLD', 0.6))
