from django.conf import settings
from django.db import models
from secrets import token_urlsafe

from ..core.models import Artist, Session

# Create your models here.

def participant_token():
    return token_urlsafe(32)

class Participant(models.Model):
    token = models.CharField(max_length=43, default=participant_token, primary_key=True)
    session = models.ForeignKey(Session, on_delete=models.CASCADE)

class Rating(models.Model):
    class Meta:
        constraints = [
            models.UniqueConstraint(fields=['artist', 'participant'], name='unique_rating'),
        ]

    value = models.CharField(max_length=2, blank=True, choices=settings.RATING_CHOICES)
    artist = models.ForeignKey(Artist, on_delete=models.CASCADE)
    participant = models.ForeignKey(Participant, on_delete=models.CASCADE)
